//! Contains utility logic.

mod approx_transportation;
pub use self::approx_transportation::*;

mod collections;
pub use self::collections::*;

mod permutations;
pub use self::permutations::VariableJobPermutation;
